@@ -8,13 +8,16 @@ import (
 	"net/http/httptest"
 	"net/url"
 	"testing"
+	"time"
 
 	"github.com/stretchr/testify/require"
 
+	"github.com/influxdata/telegraf"
 	httpconfig "github.com/influxdata/telegraf/plugins/common/http"
 	"github.com/influxdata/telegraf/plugins/common/oauth"
 	httpplugin "github.com/influxdata/telegraf/plugins/inputs/http"
 	"github.com/influxdata/telegraf/plugins/parsers"
+	"github.com/influxdata/telegraf/plugins/parsers/csv"
 	"github.com/influxdata/telegraf/testutil"
 )
 
@@ -35,11 +38,12 @@ func TestHTTPWithJSONFormat(t *testing.T) {
 	}
 	metricName := "metricName"
 
-	p, _ := parsers.NewParser(&parsers.Config{
-		DataFormat: "json",
-		MetricName: "metricName",
+	plugin.SetParserFunc(func() (telegraf.Parser, error) {
+		return parsers.NewParser(&parsers.Config{
+			DataFormat: "json",
+			MetricName: "metricName",
+		})
 	})
-	plugin.SetParser(p)
 
 	var acc testutil.Accumulator
 	require.NoError(t, plugin.Init())
@@ -78,11 +82,12 @@ func TestHTTPHeaders(t *testing.T) {
 		Log:     testutil.Logger{},
 	}
 
-	p, _ := parsers.NewParser(&parsers.Config{
-		DataFormat: "json",
-		MetricName: "metricName",
+	plugin.SetParserFunc(func() (telegraf.Parser, error) {
+		return parsers.NewParser(&parsers.Config{
+			DataFormat: "json",
+			MetricName: "metricName",
+		})
 	})
-	plugin.SetParser(p)
 
 	var acc testutil.Accumulator
 	require.NoError(t, plugin.Init())
@@ -101,12 +106,12 @@ func TestInvalidStatusCode(t *testing.T) {
 		Log:  testutil.Logger{},
 	}
 
-	metricName := "metricName"
-	p, _ := parsers.NewParser(&parsers.Config{
-		DataFormat: "json",
-		MetricName: metricName,
+	plugin.SetParserFunc(func() (telegraf.Parser, error) {
+		return parsers.NewParser(&parsers.Config{
+			DataFormat: "json",
+			MetricName: "metricName",
+		})
 	})
-	plugin.SetParser(p)
 
 	var acc testutil.Accumulator
 	require.NoError(t, plugin.Init())
@@ -126,12 +131,12 @@ func TestSuccessStatusCodes(t *testing.T) {
 		Log:                testutil.Logger{},
 	}
 
-	metricName := "metricName"
-	p, _ := parsers.NewParser(&parsers.Config{
-		DataFormat: "json",
-		MetricName: metricName,
+	plugin.SetParserFunc(func() (telegraf.Parser, error) {
+		return parsers.NewParser(&parsers.Config{
+			DataFormat: "json",
+			MetricName: "metricName",
+		})
 	})
-	plugin.SetParser(p)
 
 	var acc testutil.Accumulator
 	require.NoError(t, plugin.Init())
@@ -154,11 +159,12 @@ func TestMethod(t *testing.T) {
 		Log:    testutil.Logger{},
 	}
 
-	p, _ := parsers.NewParser(&parsers.Config{
-		DataFormat: "json",
-		MetricName: "metricName",
+	plugin.SetParserFunc(func() (telegraf.Parser, error) {
+		return parsers.NewParser(&parsers.Config{
+			DataFormat: "json",
+			MetricName: "metricName",
+		})
 	})
-	plugin.SetParser(p)
 
 	var acc testutil.Accumulator
 	require.NoError(t, plugin.Init())
@@ -170,6 +176,11 @@ const simpleJSON = `
     "a": 1.2
 }
 `
+const simpleCSVWithHeader = `
+# Simple CSV with header(s)
+a,b,c
+1.2,3.1415,ok
+`
 
 func TestBodyAndContentEncoding(t *testing.T) {
 	ts := httptest.NewServer(http.NotFoundHandler())
@@ -253,15 +264,13 @@ func TestBodyAndContentEncoding(t *testing.T) {
 				tt.queryHandlerFunc(t, w, r)
 			})
 
-			parser, err := parsers.NewParser(&parsers.Config{DataFormat: "influx"})
-			require.NoError(t, err)
-
-			tt.plugin.SetParser(parser)
+			tt.plugin.SetParserFunc(func() (telegraf.Parser, error) {
+				return parsers.NewParser(&parsers.Config{DataFormat: "influx"})
+			})
 
 			var acc testutil.Accumulator
 			require.NoError(t, tt.plugin.Init())
-			err = tt.plugin.Gather(&acc)
-			require.NoError(t, err)
+			require.NoError(t, tt.plugin.Gather(&acc))
 		})
 	}
 }
@@ -335,8 +344,10 @@ func TestOAuthClientCredentialsGrant(t *testing.T) {
 				}
 			})
 
-			parser, _ := parsers.NewValueParser("metric", "string", "", nil)
-			tt.plugin.SetParser(parser)
+			tt.plugin.SetParserFunc(func() (telegraf.Parser, error) {
+				return parsers.NewValueParser("metric", "string", "", nil)
+			})
+
 			err = tt.plugin.Init()
 			require.NoError(t, err)
 
@@ -346,3 +357,55 @@ func TestOAuthClientCredentialsGrant(t *testing.T) {
 		})
 	}
 }
+
+func TestHTTPWithCSVFormat(t *testing.T) {
+	fakeServer := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
+		if r.URL.Path == "/endpoint" {
+			_, _ = w.Write([]byte(simpleCSVWithHeader))
+		} else {
+			w.WriteHeader(http.StatusNotFound)
+		}
+	}))
+	defer fakeServer.Close()
+
+	address := fakeServer.URL + "/endpoint"
+	plugin := &httpplugin.HTTP{
+		URLs: []string{address},
+		Log:  testutil.Logger{},
+	}
+
+	plugin.SetParserFunc(func() (telegraf.Parser, error) {
+		parser := &csv.Parser{
+			MetricName:  "metricName",
+			SkipRows:    3,
+			ColumnNames: []string{"a", "b", "c"},
+			TagColumns:  []string{"c"},
+		}
+		err := parser.Init()
+		return parser, err
+	})
+
+	expected := []telegraf.Metric{
+		testutil.MustMetric("metricName",
+			map[string]string{
+				"url": address,
+				"c":   "ok",
+			},
+			map[string]interface{}{
+				"a": 1.2,
+				"b": 3.1415,
+			},
+			time.Unix(0, 0),
+		),
+	}
+
+	var acc testutil.Accumulator
+	require.NoError(t, plugin.Init())
+	require.NoError(t, acc.GatherError(plugin.Gather))
+	testutil.RequireMetricsEqual(t, expected, acc.GetTelegrafMetrics(), testutil.IgnoreTime())
+
+	// Run the parser a second time to test for correct stateful handling
+	acc.ClearMetrics()
+	require.NoError(t, acc.GatherError(plugin.Gather))
+	testutil.RequireMetricsEqual(t, expected, acc.GetTelegrafMetrics(), testutil.IgnoreTime())
+}
