@@ -69,8 +69,13 @@ func TestWinPerformanceQueryImplIntegration(t *testing.T) {
 	err = query.CollectData()
 	require.NoError(t, err)
 
-	_, err = query.GetFormattedCounterValueDouble(hCounter)
+	fcounter, err := query.GetFormattedCounterValueDouble(hCounter)
 	require.NoError(t, err)
+	require.True(t, fcounter > 0)
+
+	rcounter, err := query.GetRawCounterValue(hCounter)
+	require.NoError(t, err)
+	require.True(t, rcounter > 10000000)
 
 	now := time.Now()
 	mtime, err := query.CollectDataWithTime()
@@ -104,13 +109,17 @@ func TestWinPerformanceQueryImplIntegration(t *testing.T) {
 	err = query.CollectData()
 	require.NoError(t, err)
 
-	arr, err := query.GetFormattedCounterArrayDouble(hCounter)
+	farr, err := query.GetFormattedCounterArrayDouble(hCounter)
 	if phderr, ok := err.(*PdhError); ok && phderr.ErrorCode != PDH_INVALID_DATA && phderr.ErrorCode != PDH_CALC_NEGATIVE_VALUE {
 		time.Sleep(time.Second)
-		arr, err = query.GetFormattedCounterArrayDouble(hCounter)
+		farr, err = query.GetFormattedCounterArrayDouble(hCounter)
 	}
 	require.NoError(t, err)
-	require.True(t, len(arr) > 0, "Too")
+	require.True(t, len(farr) > 0)
+
+	rarr, err := query.GetRawCounterArray(hCounter)
+	require.NoError(t, err)
+	require.True(t, len(rarr) > 0, "Too")
 
 	err = query.Close()
 	require.NoError(t, err)
@@ -144,8 +153,13 @@ func TestWinPerfcountersConfigGet1Integration(t *testing.T) {
 
 	perfobjects[0] = PerfObject
 
-	m := Win_PerfCounters{PrintValid: false, Object: perfobjects, query: &PerformanceQueryImpl{}}
-	m.query.Open()
+	m := Win_PerfCounters{
+		PrintValid: false,
+		Object:     perfobjects,
+		query:      &PerformanceQueryImpl{},
+		Log:        testutil.Logger{},
+	}
+	_ = m.query.Open()
 
 	err := m.ParseConfig()
 	require.NoError(t, err)
@@ -178,8 +192,13 @@ func TestWinPerfcountersConfigGet2Integration(t *testing.T) {
 
 	perfobjects[0] = PerfObject
 
-	m := Win_PerfCounters{PrintValid: false, Object: perfobjects, query: &PerformanceQueryImpl{}}
-	m.query.Open()
+	m := Win_PerfCounters{
+		PrintValid: false,
+		Object:     perfobjects,
+		query:      &PerformanceQueryImpl{},
+		Log:        testutil.Logger{},
+	}
+	_ = m.query.Open()
 
 	err := m.ParseConfig()
 	require.NoError(t, err)
@@ -225,8 +244,13 @@ func TestWinPerfcountersConfigGet3Integration(t *testing.T) {
 
 	perfobjects[0] = PerfObject
 
-	m := Win_PerfCounters{PrintValid: false, Object: perfobjects, query: &PerformanceQueryImpl{}}
-	m.query.Open()
+	m := Win_PerfCounters{
+		PrintValid: false,
+		Object:     perfobjects,
+		query:      &PerformanceQueryImpl{},
+		Log:        testutil.Logger{},
+	}
+	_ = m.query.Open()
 
 	err := m.ParseConfig()
 	require.NoError(t, err)
@@ -274,8 +298,13 @@ func TestWinPerfcountersConfigGet4Integration(t *testing.T) {
 
 	perfobjects[0] = PerfObject
 
-	m := Win_PerfCounters{PrintValid: false, Object: perfobjects, query: &PerformanceQueryImpl{}}
-	m.query.Open()
+	m := Win_PerfCounters{
+		PrintValid: false,
+		Object:     perfobjects,
+		query:      &PerformanceQueryImpl{},
+		Log:        testutil.Logger{},
+	}
+	_ = m.query.Open()
 
 	err := m.ParseConfig()
 	require.NoError(t, err)
@@ -324,8 +353,13 @@ func TestWinPerfcountersConfigGet5Integration(t *testing.T) {
 
 	perfobjects[0] = PerfObject
 
-	m := Win_PerfCounters{PrintValid: false, Object: perfobjects, query: &PerformanceQueryImpl{}}
-	m.query.Open()
+	m := Win_PerfCounters{
+		PrintValid: false,
+		Object:     perfobjects,
+		query:      &PerformanceQueryImpl{},
+		Log:        testutil.Logger{},
+	}
+	_ = m.query.Open()
 
 	err := m.ParseConfig()
 	require.NoError(t, err)
@@ -370,8 +404,13 @@ func TestWinPerfcountersConfigGet6Integration(t *testing.T) {
 
 	perfobjects[0] = PerfObject
 
-	m := Win_PerfCounters{PrintValid: false, Object: perfobjects, query: &PerformanceQueryImpl{}}
-	m.query.Open()
+	m := Win_PerfCounters{
+		PrintValid: false,
+		Object:     perfobjects,
+		query:      &PerformanceQueryImpl{},
+		Log:        testutil.Logger{},
+	}
+	_ = m.query.Open()
 
 	err := m.ParseConfig()
 	require.NoError(t, err)
@@ -402,12 +441,18 @@ func TestWinPerfcountersConfigGet7Integration(t *testing.T) {
 		false,
 		false,
 		false,
+		false,
 	}
 
 	perfobjects[0] = PerfObject
 
-	m := Win_PerfCounters{PrintValid: false, Object: perfobjects, query: &PerformanceQueryImpl{}}
-	m.query.Open()
+	m := Win_PerfCounters{
+		PrintValid: false,
+		Object:     perfobjects,
+		query:      &PerformanceQueryImpl{},
+		Log:        testutil.Logger{},
+	}
+	_ = m.query.Open()
 
 	err := m.ParseConfig()
 	require.NoError(t, err)
@@ -458,7 +503,7 @@ func TestWinPerfcountersConfigError1Integration(t *testing.T) {
 		query:      &PerformanceQueryImpl{},
 		Log:        testutil.Logger{},
 	}
-	m.query.Open()
+	_ = m.query.Open()
 
 	err := m.ParseConfig()
 	require.Error(t, err)
@@ -497,7 +542,7 @@ func TestWinPerfcountersConfigError2Integration(t *testing.T) {
 		query:      &PerformanceQueryImpl{},
 		Log:        testutil.Logger{},
 	}
-	m.query.Open()
+	_ = m.query.Open()
 
 	err := m.ParseConfig()
 	var acc testutil.Accumulator
@@ -538,7 +583,7 @@ func TestWinPerfcountersConfigError3Integration(t *testing.T) {
 		query:      &PerformanceQueryImpl{},
 		Log:        testutil.Logger{},
 	}
-	m.query.Open()
+	_ = m.query.Open()
 
 	err := m.ParseConfig()
 	require.Error(t, err)
@@ -647,3 +692,77 @@ func TestWinPerfcountersCollect2Integration(t *testing.T) {
 	}
 
 }
+
+func TestWinPerfcountersCollectRawIntegration(t *testing.T) {
+	if testing.Short() {
+		t.Skip("Skipping integration test in short mode")
+	}
+	var instances = make([]string, 1)
+	var counters = make([]string, 1)
+	var perfobjects = make([]perfobject, 1)
+
+	objectname := "Processor"
+	instances[0] = "*"
+	counters[0] = "% Idle Time"
+
+	var expectedCounter = "Percent_Idle_Time_Raw"
+
+	var measurement = "test"
+
+	PerfObject := perfobject{
+		ObjectName:    objectname,
+		Instances:     instances,
+		Counters:      counters,
+		Measurement:   measurement,
+		WarnOnMissing: false,
+		FailOnMissing: true,
+		IncludeTotal:  false,
+		UseRawValues:  true,
+	}
+
+	perfobjects[0] = PerfObject
+
+	m := Win_PerfCounters{
+		PrintValid:            false,
+		Object:                perfobjects,
+		UseWildcardsExpansion: true,
+		query:                 &PerformanceQueryImpl{},
+		Log:                   testutil.Logger{},
+	}
+	var acc testutil.Accumulator
+	err := m.Gather(&acc)
+	require.NoError(t, err)
+
+	time.Sleep(2000 * time.Millisecond)
+	err = m.Gather(&acc)
+	require.NoError(t, err)
+	require.True(t, len(acc.Metrics) > 1)
+
+	for _, metric := range acc.Metrics {
+		val, ok := metric.Fields[expectedCounter]
+		require.True(t, ok, "Expected presence of %s field", expectedCounter)
+		valInt64, ok := val.(int64)
+		require.True(t, ok, fmt.Sprintf("Expected int64, got %T", val))
+		require.True(t, valInt64 > 0, fmt.Sprintf("Expected > 0, got %d, for %#v", valInt64, metric))
+	}
+
+	// Test *Array way
+	m = Win_PerfCounters{PrintValid: false, Object: perfobjects, UseWildcardsExpansion: false, query: &PerformanceQueryImpl{}, Log: testutil.Logger{}}
+	var acc2 testutil.Accumulator
+	err = m.Gather(&acc)
+	require.NoError(t, err)
+
+	time.Sleep(2000 * time.Millisecond)
+	err = m.Gather(&acc2)
+	require.NoError(t, err)
+	require.True(t, len(acc2.Metrics) > 1)
+
+	for _, metric := range acc2.Metrics {
+		val, ok := metric.Fields[expectedCounter]
+		require.True(t, ok, "Expected presence of %s field", expectedCounter)
+		valInt64, ok := val.(int64)
+		require.True(t, ok, fmt.Sprintf("Expected int64, got %T", val))
+		require.True(t, valInt64 > 0, fmt.Sprintf("Expected > 0, got %d, for %#v", valInt64, metric))
+	}
+
+}
